type config = {
  key_left: string;
  key_up : string;
  key_down : string;
  key_right : string;
}

(* On crée une fenêtre *)
let window = Gfx.create (Format.sprintf "game_canvas:%dx%d:" 800 600)
let window_surf = Gfx.get_surface window
let ctx = Gfx.get_context window

let draw_rect col x y w h =
  Gfx.set_color ctx col;
  Gfx.fill_rect ctx window_surf x y w h

let colors =
  [| Gfx.color 255 0 0 255; Gfx.color 0 255 0 255; Gfx.color 0 0 255 255 |]

let idx = ref 0
let last_dt = ref 0.0
let x = ref 100
let y = ref 100
let keys = Hashtbl.create 16
let white = Gfx.color 255 255 255 2555
let update cfg dt =
  let () =
    match Gfx.poll_event () with
      Gfx.NoEvent -> ()
      | Gfx.KeyDown s -> Gfx.debug "%s@\n%!" s; Hashtbl.replace keys s ()
      | Gfx.KeyUp s -> Hashtbl.remove keys s
  in
  if Hashtbl.mem keys cfg.key_left then x := !x - 10;
  if Hashtbl.mem keys cfg.key_right then x := !x + 10;
  if Hashtbl.mem keys cfg.key_up then y := !y - 10;
  if Hashtbl.mem keys cfg.key_down then y := !y + 10;

  if dt -. !last_dt > 1000.0 then begin
    Gfx.debug "%f@\n%!" dt;
    idx := (!idx + 1) mod Array.length colors;
    last_dt := dt
  end;
  draw_rect white 0 0 800 600;
  draw_rect colors.(!idx) !x !y 200 200;
  Gfx.commit ctx;
  not (Hashtbl.mem keys "q")

let run cfg = Gfx.main_loop (update cfg)
